// ----------------------------------------------------------------------------------------------------
// Configuration settings for HP Service Manager Integration v4.1
// ----------------------------------------------------------------------------------------------------
var HPSM_URL = "http://localhost:13080/sc62server/ws";  // Note that this URL is case-sensitive.  Communication from the 
                                                        // Integration Agent to HP Service Manager will fail if this is not correct.

// Specifies the default HP Service Manager login credentials to use when a User has not specified values for the custom fields or for callout annotations
var HPSM_USER_NAME = "falcon";
                                                     
// location of the hp sm password file
var HPSM_PASSWORD_FILE = "conf/hpsmim.pwd";

// xMatters user custom fields required for user impersonation
var HPSM_LOGIN_CUSTOM_FIELD = "sm_user";
var HPSM_PASSWORD_CUSTOM_FIELD = "sm_password";

// When set to 'true', the impersonation is turned off and integration will always use default credentials even if user has custom properties set.
// Default value is 'false'
var USE_DEFAULT_CREDENTIALS = false;  

// Specifies the behavior if impersonation is enabled but the user does not have custom properties set:
//   'true' : response options are removed from user notifications; responses from these users to group notifications will be logged but not processed.
//  'false' : (default behavior) response options are always present; responses from users with no credentials will be processed using default credentials.
var ENFORCE_CUSTOM_FIELDS = false;  // Note that group notifications will always have response options.

//----------------------------------------------------------------------------------------------------
// Web Service URLs of HP SM IM Communication Plan forms used to inject events
//
// Format : '<trigger rule>' : "<Form's Web Service URL>"
//----------------------------------------------------------------------------------------------------
var FORMS = {
'Assignment'        : "<Web Service URL for Incident Assigned Alert form>",
'Priority Upgrade'  : "<Web Service URL for Incident Priority Upgrade Alert form>", 
'Ticket Resolved'   : "<Web Service URL for Incident Resolved Alert form>",
'Ticket Reopened'   : "<Web Service URL for Reopened Incident Alert form>",
'New Ticket'        : "<Web Service URL for New Incident Alert form>"
}

WEB_SERVICE_URL = FORMS['Assignment'];	// The url that will be used as base for REST API operations such as "get events"

//----------------------------------------------------------------------------------------------------
// Response options for forms when incident is assigned to the user. By default, all response options are used
//
// Format : '<trigger rule>' : [ '<Response Identifier>', ... ]
//
// Example: 'Assignment' : [ '13ca2237-e5ff-4de7-baa8-2b3fd0a79cb6', '51d1d628-ed90-4668-8417-0877f3cf6791' ]
//----------------------------------------------------------------------------------------------------

RESPONSE_OPTIONS_WHEN_ASSIGNED_TO_USER = {
  // Out of the box, only Escalate and Resolve response options are available when incident is assigned to the user
  // Note that there is no entry for "Ticket Resolved" trigger rule as Incident Resolved Alert form has no response options
  
  'Assignment'       : [ '<Escalate Response Identifier>', '<Resolve Response Identifier>' ], // Incident Assigned Alert response IDs
  'Priority Upgrade' : [ '<Escalate Response Identifier>', '<Resolve Response Identifier>' ], // Incident Priority Upgrade Alert response IDs
  'Ticket Reopened'  : [ '<Escalate Response Identifier>', '<Resolve Response Identifier>' ]  // Reopened Incident Alert response IDs
};

//----------------------------------------------------------------------------------------------------
// Response options when incident is assigned to the group.
//
// Format : '<trigger rule>' : [ '<Response Identifier>', ... ]
//----------------------------------------------------------------------------------------------------

RESPONSE_OPTIONS_WHEN_ASSIGNED_TO_GROUP = {
  // Out of the box, all response options defined in the form are available when incident is assigned to the group
};

//----------------------------------------------------------------------------------------------------
// Web Service URL of a form to be used when response updates fail in HP SM
//----------------------------------------------------------------------------------------------------
var ERROR_FORM = "<Form's Web Service URL>";

//----------------------------------------------------------------------------------------------------
// Web Service URL of a form to be used when data sync fails in HP SM
//----------------------------------------------------------------------------------------------------
var SYNC_ERROR_FORM = "<Form's Web Service URL>"

//----------------------------------------------------------------------------------------------------
// The Web Login ID used to authenticate the request to xMatters. The user's password should be encrypted
// using the iapassword.sh utility. Please see the integration agent documentation for instructions.
//----------------------------------------------------------------------------------------------------
INITIATOR = "hpsmim"; 
PASSWORD = "conf/.initiatorpasswd";

// ----------------------------------------------------------------------------------------------------
// Integrated properties names mapping 
// ----------------------------------------------------------------------------------------------------
var INTEGRATED_PROPERTIES = {
// Name as returned by HP SM    xM Integrated Property Name 
  'OpenedBy'                  :      'Opened By',
  'OpenTime'                  :      'Opened On',
  'AssignmentGroup'           :      'Assignment Group',
  'TicketOwner'               :      'Owner',
  'UpdatedBy'                 :      'Updated By',
  'UpdatedTime'               :      'Updated On',
  'Service'                   :      'Affected Service'
};

// ----------------------------------------------------------------------------------------------------
// Filter to use in <IAHOME>/conf/deduplicator-filter.xml
// ----------------------------------------------------------------------------------------------------
DEDUPLICATION_FILTER_NAME = "hpsmim-4-1";

// Sends a delete prior to creating the new event to clear out any existing events for this Incident ID
// Default value is 'false', as HP SM script explicitly injects "DEL" when events are to be terminated. 
var DELETE_EXISTING_EVENTS = false;

// Update events with xMatters notification delivery status.
var ANNOTATE_DELIVERY = true;

// Properties that have special meaning for integration script
var PROPERTY_TRIGGER_RULE  = 'trigger_rule';
var PROPERTY_TICKET_ID     = 'incident_id';
var PROPERTY_ASSIGNEE_NAME = 'assignee_name';

// Integration properties form IncidentID
var INT_PROPERTY_TICKET_ID = 'Incident ID';

// Response actions (use lowercase)
var RESPONSE_ACTION_OWN       = "own";
var RESPONSE_ACTION_ESCALATE  = "escalate";
var RESPONSE_ACTION_RESOLVE   = "resolve";
var RESPONSE_ACTION_ACK       = "ack";
var RESPONSE_ACTION_ACKNOWLEDGE  = "acknowledge";

// Properties of xMatters event created in case of exception while processing the user response
var ERROR_MESSAGE_BODY      = "error_message";
var ERROR_MESSAGE_SUBJECT   = "error_subject";
var ERROR_MESSAGE_RESPONSE  = "error_response";

// Priority of xMatters event created in case of exception while processing the user response
var ERROR_MESSAGE_PRIORITY = "low";

