
function apia_remapped_data() {
  return {
    "priority" : "priority"
  }
}

function apia_event(form) {

  // APXML event injection has been converted to a JavaScript object
  // that can be serialized and sent to xMatters.
  
  if (IALOG.isDebugEnabled()) {
    IALOG.debug("{0}: JSON received {1}", form.properties[PROPERTY_TICKET_ID], JSON.stringify(form, null, 2));
  }

  // A workaround for 'form properties of type List rejecting empty values' issue
  for (var property in form.properties) {
    if (form.properties[property] === "") {
      form.properties[property] = null;
    }
  }

  if ( form.properties[PROPERTY_TRIGGER_RULE] ) {
    // Set up responses
    var isAssignedToUser = form.properties[PROPERTY_ASSIGNEE_NAME];
    var response_options = isAssignedToUser ? 
        RESPONSE_OPTIONS_WHEN_ASSIGNED_TO_USER : RESPONSE_OPTIONS_WHEN_ASSIGNED_TO_GROUP;

    var responses = response_options[ form.properties[PROPERTY_TRIGGER_RULE] ];
    
    if (isAssignedToUser && !USE_DEFAULT_CREDENTIALS && ENFORCE_CUSTOM_FIELDS) {
      // Check if user credentials are set
      var user = getUser(form.properties[PROPERTY_ASSIGNEE_NAME]);
      
      var username = user.customFields.get(HPSM_LOGIN_CUSTOM_FIELD);
      var password = user.customFields.get(HPSM_PASSWORD_CUSTOM_FIELD);
      
      if ( username == null || username == "" || password == null || password == "" || password == "[]") {
        IALOG.warn("{0}: Custom fields '{1}' and/or '{2}' are missing for user {3}, which are both manditory for processing of the response. Response options will be removed.", 
          form.properties[PROPERTY_TICKET_ID], HPSM_LOGIN_CUSTOM_FIELD, HPSM_PASSWORD_CUSTOM_FIELD, form.properties[PROPERTY_ASSIGNEE_NAME]);
        form.responses = [];
        responses = null;
      }
    }

    if (responses != null) {
      IALOG.info("{0}: added {1} responses", form.properties[PROPERTY_TICKET_ID], responses.length);
      form.responses = responses;
    }
  } else { // Sync error or error
    form.callbacks = []; // Remove callbacks as no annotations are required
  }
  
  return form;
}

// Overrides event.js implementation to support multiple forms
function apia_input(apxml) {
  var method = String(apxml.getMethod());
  
  switch (method) {
  
    case "del": // Terminate event
    
      var incidentId = apxml.getValue(PROPERTY_TICKET_ID);
      
      IALOG.info("{0}: Received request to terminate events", incidentId); 
      IALOG.debug("{0}: WEB_SERVICE_URL={1}, INITIATOR={2}, PASSWORD={3}", incidentId, WEB_SERVICE_URL, INITIATOR, PASSWORD); 

      if (incidentId != null) {
        var count = XMRESTAPI.deleteEvents( WEB_SERVICE_URL, getExistingEventsFilter(incidentId) ); // deleteEvents will throw exception if something is wrong
        IALOG.info("{0}: Events terminated: {1}", incidentId, count);
      } else {
        throw "incident_id token is missing";       
      }
      break;
      
    case "add": // Inject event
    
      var incidentId = apxml.getValue(PROPERTY_TICKET_ID);
      
      IALOG.info("{0}: Received request to inject event", incidentId);    
      IALOG.debug("{0}: WEB_SERVICE_URL={1}, INITIATOR={2}, PASSWORD={3}", incidentId, WEB_SERVICE_URL, INITIATOR, PASSWORD); 

      var response = XMRESTAPI.submitApxml( getFormURL(apxml), apxml, DELETE_EXISTING_EVENTS ? getExistingEventsFilter(incidentId) : null, null );
      if (response) {
        // if request was actually sent
        if (response.status == XMRESTAPI.RESPONSE_SUCCESS) {
          var recipients = JSON.parse(apxml.getValue("recipients"))
          IALOG.info("{0}: Event {1} was sent to {2}", incidentId, JSON.parse(response.body).id, recipients && recipients.length > 0 ? recipients[0].targetName : "form"); 
        } else {
          IALOG.warn("{0}: FAILURE ({1})", incidentId, response.status);      
          XMRESTAPI.checkResponse( response );
        }
      }      
      break;
      
    default:
      IALOG.warn("Method '{0}' is not supported", method);
  }
}

// Get URL of the form that will handle this request
function getFormURL( apxml ) {
  if ("SYNC_ERROR" == apxml.getValue(PROPERTY_TICKET_ID)) {
    return SYNC_ERROR_FORM;
  }
  
  var truggerRule = apxml.getValue(PROPERTY_TRIGGER_RULE);
  if (!truggerRule in FORMS) {
    throw "Form URL is not defined for trigger rule '" + triggerRule + "'";
  }  

  return FORMS[truggerRule];
}

/**
 * ---------------------------------------------------------------------------------------------------------------------
 * getExistingEventsFilter
 * @param incidentId ID of the incident ticket
 *
 * return a Javascript object that contains the event filter parameters 
 * ---------------------------------------------------------------------------------------------------------------------
 */
function getExistingEventsFilter(incidentId) {
  return { status : "ACTIVE", properties : { 'incident_id#en' : incidentId } } 
}
