importPackage(Packages.com.alarmpoint.servicemanager);

var INT_VERSION = "hpsmim-4-1";

load("integrationservices/" + INT_VERSION + "/configuration.js");

// REST API support 
load("lib/integrationservices/javascript/log.js");
load("lib/integrationservices/javascript/xmutil.js");
load("lib/integrationservices/javascript/xmio.js");

load("integrationservices/" + INT_VERSION + "/apxml.js");
load("integrationservices/" + INT_VERSION + "/xmrestapi.js");

// Core Javascript files provided by the IA Utils
load("integrationservices/" + INT_VERSION + "/lib/javascript/core/baseclass.js");
load("integrationservices/" + INT_VERSION + "/lib/javascript/core/logger.js");
load("integrationservices/" + INT_VERSION + "/lib/javascript/core/util.js");

load("integrationservices/" + INT_VERSION + "/lib/javascript/webservices/wsutil.js");
load("integrationservices/" + INT_VERSION + "/lib/javascript/webservices/soapfault.js");
load("integrationservices/" + INT_VERSION + "/lib/javascript/xmatters/xmattersws.js");

load("integrationservices/" + INT_VERSION + "/lib/javascript/xmatters/dataSyncUser.js");

// Integration files
load("integrationservices/" + INT_VERSION + "/hpsmim-events.js");
load("integrationservices/" + INT_VERSION + "/hpsmim-callbacks.js");
load("integrationservices/" + INT_VERSION + "/hpsmim-properties.js");

// ---------------------------------------------------------------------------------------------------------------------

var HPSM_PASSWORD = XMIO.decryptFile(HPSM_PASSWORD_FILE);

var notePrefix = "[xMatters] - "; // The Prefix which is added to the note comments e.g. "[xMatters] "
var closureCode = "Fault"; // This should be modified to the appropriate closure code for the integration
var resolutionText = "Resolved using xMatters"; // This will be passed as "solution" field value when incident is resolved

var exceptionString = "JavaException: ";
var LOCKED_RECORD_INDICATOR = "Requested resource is in use by"; // an indicator of Service Manager's "Record is locked" exception 

/**
 * ---------------------------------------------------------------------------------------------------------------------
 * addAnnotation
 *
 * Adds an annotation to HP SM incident 
 *
 * @param incidentId incident to annotate
 * @param message
 * ---------------------------------------------------------------------------------------------------------------------
 */
function addAnnotation( incidentId, message ) {
  
  IALOG.debug("{0}: addAnnotation '{1}' as user {2}", incidentId, message, HPSM_USER_NAME);
  
  try {
    // create the connection to the SM Script Object as default user for delivery annotations
    var smConnection = ServiceManagerScriptObject( HPSM_URL, HPSM_USER_NAME, HPSM_PASSWORD );

    smConnection.updateIncident(incidentId, notePrefix + message);
    
  } catch (e) {
    IALOG.warn("{0}: Caught exception: {1}", incidentId, e);
  }        
}

/**
 * ---------------------------------------------------------------------------------------------------------------------
 * getIncidentID
 *
 * Check whether additionalTokens and incident_id are present, and return the content if they are. 
 * If not, an exception is thrown.
 *
 * @param msg
 * ---------------------------------------------------------------------------------------------------------------------
 */
function getIncidentID( msg ) { 
  if (INT_PROPERTY_TICKET_ID in msg.additionalTokens)
    return getProperty( msg, INT_PROPERTY_TICKET_ID );
  else
    return getProperty( msg, PROPERTY_TICKET_ID );
}

/**
 * ---------------------------------------------------------------------------------------------------------------------
 * getProperty
 *
 * Check whether additionalTokens and property with propertyName name are present, and return the content if they are. 
 * If not, an exception is thrown.
 *
 * @param msg
 * @param propertyName
 * ---------------------------------------------------------------------------------------------------------------------
 */
function getProperty( msg, propertyName, defaultValue ) {
  var hasID = ('additionalTokens' in msg) && (propertyName in msg.additionalTokens);
  
  if ( !hasID ) {
    if (typeof defaultValue !== "undefined") {
      return defaultValue;
    } else {
      throw { name: "DataException", message: propertyName + " property is not found in event callback data of type " + msg.xmatters_callback_type + " for event ID " + msg.eventidentifier 
        + ". Make sure 'Include in Callbacks' is set for " + propertyName + " property in the form's layout"};
    }
  }
  
  return msg.additionalTokens[propertyName];
}

/**
 * ---------------------------------------------------------------------------------------------------------------------
 * getUser
 *
 * Get User object from xMatters by username
 *
 * @param targetName xMatters user name
 * @param propertyName
 * ---------------------------------------------------------------------------------------------------------------------
 */
function getUser(targetName) {
  var user = new User(targetName);

  if (!user.exists()) {
    throw "Unknown user " + targetName;
  }
  
  if (IALOG.isDebugEnabled()) {
    var customFields = user.customFields;
    IALOG.debug("Got {0} custom fields: {1}", customFields.size(), customFields);
  }
  
  return user;
}
